coherence.backends.dvbd_storage (module) — Cohen3 0.8.0 documentation

# coherence.backends.dvbd_storage (module)

class `Container`(id, parent_id, name, store=None, children_callback=None, container_class=<class 'coherence.upnp.core.DIDLLite.Container'>)

  Bases: `coherence.backend.BackendItem`

  `logCategory` = 'dvbd_store'
  `add_child`(child)
  `get_children`(start=0, end=0)

    Called by the CDS and the MediaServer web.

    Parameters: | start (int) – the start. end (int) – the end.
    Returns: | a list of its childs, from start to end. or a Deferred

  `remove_children`()
  `get_child_count`()

    Called by the CDS.

    Returns: | the number of its childs - len(childs) or a Deferred

  `get_item`()

    Called by the CDS and the MediaServer web.

    Returns: | an UPnP ContentDirectoryServer DIDLLite object or a Deferred

  `get_name`()

    Called by the MediaServer web.

    Returns: | the name of the item, it is always expected to be in unicode.

  `get_id`()

class `Channel`(store, id, parent_id, name, url, network, mimetype)

  Bases: `coherence.backend.BackendItem`

  `logCategory` = 'dvbd_store'
  `get_children`(start=0, end=0)

    Called by the CDS and the MediaServer web.

    Parameters: | start (int) – the start. end (int) – the end.
    Returns: | a list of its childs, from start to end. or a Deferred

  `get_child_count`()

    Called by the CDS.

    Returns: | the number of its childs - len(childs) or a Deferred

  `get_item`(parent_id=None)

    Called by the CDS and the MediaServer web.

    Returns: | an UPnP ContentDirectoryServer DIDLLite object or a Deferred

  `get_id`()
  `get_name`()

    Called by the MediaServer web.

    Returns: | the name of the item, it is always expected to be in unicode.

class `Recording`(store, id, parent_id, file, title, date, duration, mimetype)

  Bases: `coherence.backend.BackendItem`

  `logCategory` = 'dvbd_store'
  `get_children`(start=0, end=0)

    Called by the CDS and the MediaServer web.

    Parameters: | start (int) – the start. end (int) – the end.
    Returns: | a list of its childs, from start to end. or a Deferred

  `get_child_count`()

    Called by the CDS.

    Returns: | the number of its childs - len(childs) or a Deferred

  `get_item`(parent_id=None)

    Called by the CDS and the MediaServer web.

    Returns: | an UPnP ContentDirectoryServer DIDLLite object or a Deferred

  `get_id`()
  `get_name`()

    Called by the MediaServer web.

    Returns: | the name of the item, it is always expected to be in unicode.

  `get_url`()
  `get_path`()

    Called by the MediaServer web.

    Returns: | the filepath where to find the media file that this item does refer to.

class `DVBDStore`(server, **kwargs)

  Bases: `coherence.backend.BackendStore`

  This is a backend to the DVB Daemon:
    http://www.k-d-w.org/node/42

  Changed in version 0.9.0: Migrated from louie/dispatcher to EventDispatcher

  `implements` = ['MediaServer']
  `logCategory` = 'dvbd_store'
  `get_by_id`(id)

    Parameters: | id (object) – is the id property of our DIDLLite item
    Returns: | None when no matching item for that id is found, a BackendItem, or a Deferred

    Called by the CDS or the MediaServer web.

    Note

    if this MediaServer implements containers that can share their content, like ‘all tracks’, ‘album’ and ‘album_of_artist’ (they all have the same track item as content), then the id may be passed by the CDS like this:

    > ‘id@container’ or ‘id@container@container@container…’

    therefore a

        if isinstance(id, basestring):
            id = id.split('@',1)
            id = id[0]

    may be appropriate as the first thing to do when entering this method.

  `recording_changed`(id, mode)
  `get_recording_details`(id)
  `get_recordings`()
  `get_channel_details`(channelList_interface, id)
  `get_channelgroup_members`(channel_items, channelList_interface)
  `get_tv_channels`(channelList_interface)
  `get_deviceGroup_details`(devicegroup_interface)
  `get_device_groups`(results)
  `get_channel_groups`()
  `upnp_init`()

    This method gets called after the device is fired, here all initializations of service related state variables should happen, as the services aren’t available before that point.

  `hidden_upnp_DestroyObject`(*args, **kwargs)

class `DVBDScheduledRecording`(server, **kwargs)

  Bases: `coherence.backend.BackendStore`

  `logCategory` = 'dvbd_store'
  `get_timer_details`(tid)
  `get_timers`()
  `add_timer`(channel_id, start_datetime, duration)
  `delete_timer`(tid)
  `upnp_GetPropertyList`(*args, **kwargs)
  `upnp_GetAllowedValues`(*args, **kwargs)
  `upnp_GetStateUpdateID`(*args, **kwargs)
  `upnp_BrowseRecordSchedules`(*args, **kwargs)
  `upnp_BrowseRecordTasks`(*args, **kwargs)
  `upnp_CreateRecordSchedule`(*args, **kwargs)
  `upnp_DeleteRecordSchedule`(*args, **kwargs)
  `upnp_GetRecordSchedule`(*args, **kwargs)
  `upnp_GetRecordTask`(*args, **kwargs)